@@ -23,6 +23,8 @@ from contextlib import contextmanager
 import logging
 
 from vdsm import jobs
+from vdsm import utils
+
 from vdsm.common import properties
 from vdsm.storage import constants as sc
 from vdsm.storage import guarded
@@ -80,11 +82,14 @@ class Job(base.Job):
                         dstQcow2Compat=self._dest.qcow2_compat,
                         backing=self._dest.backing_path,
                         backingFormat=self._dest.backing_qemu_format,
-                        preallocation=self._dest.preallocation,
                         unordered_writes=self._dest
                             .recommends_unordered_writes,
-                        create=not self._dest.volume.is_block())
-                    self._operation.run()
+                        create=self._dest.requires_create)
+                    with utils.stopwatch(
+                            "Copy volume {}".format(self._source.path),
+                            level=logging.INFO,
+                            log=self.log):
+                        self._operation.run()
 
 
 def _create_endpoint(params, host_id, writable):
@@ -154,19 +159,15 @@ class CopyDataDivEndpoint(properties.Owner):
             return None
         return sc.fmt2str(parent_vol.getFormat())
 
-    @property
-    def preallocation(self):
-        dom = sdCache.produce_manifest(self.sd_id)
-        if (dom.supportsSparseness and
-                self.volume.getType() == sc.PREALLOCATED_VOL):
-            return qemuimg.PREALLOCATION.FALLOC
-        return None
-
     @property
     def recommends_unordered_writes(self):
         dom = sdCache.produce_manifest(self.sd_id)
         return dom.recommends_unordered_writes(self.volume.getFormat())
 
+    @property
+    def requires_create(self):
+        return self.volume.requires_create()
+
     @property
     def volume(self):
         if self._vol is None:
